@@ -105,7 +105,7 @@ void GData::listBlogs()
            SIGNAL(loadingComplete(Syndication::Loader*,Syndication::FeedPtr,Syndication::ErrorCode)),
            this,
            SLOT(slotListBlogs(Syndication::Loader*,Syndication::FeedPtr,Syndication::ErrorCode)) );
-  loader->loadFrom( "http://www.blogger.com/feeds/" + profileId() + "/blogs" );
+  loader->loadFrom( QString::fromLatin1("http://www.blogger.com/feeds/%1/blogs").arg(profileId()) );
 }
 
 void GData::listRecentPosts( const QStringList &labels, int number,
@@ -164,8 +164,8 @@ void GData::listComments( KBlog::BlogPost *post )
            SIGNAL(loadingComplete(Syndication::Loader*,Syndication::FeedPtr,Syndication::ErrorCode)),
            this,
            SLOT(slotListComments(Syndication::Loader*,Syndication::FeedPtr,Syndication::ErrorCode)) );
-  loader->loadFrom( "http://www.blogger.com/feeds/" + blogId() + '/' +
-                    post->postId() + "/comments/default" );
+  loader->loadFrom( QString("http://www.blogger.com/feeds/" + blogId() + '/' +
+                    post->postId() + "/comments/default") );
 }
 
 void GData::listAllComments()
@@ -176,7 +176,7 @@ void GData::listAllComments()
            SIGNAL(loadingComplete(Syndication::Loader*,Syndication::FeedPtr,Syndication::ErrorCode)),
            this,
            SLOT(slotListAllComments(Syndication::Loader*,Syndication::FeedPtr,Syndication::ErrorCode)) );
-  loader->loadFrom( "http://www.blogger.com/feeds/" + blogId() + "/comments/default" );
+  loader->loadFrom( QString::fromLatin1("http://www.blogger.com/feeds/%1/comments/default").arg(blogId()) );
 }
 
 void GData::fetchPost( KBlog::BlogPost *post )
@@ -196,7 +196,7 @@ void GData::fetchPost( KBlog::BlogPost *post )
            SIGNAL(loadingComplete(Syndication::Loader*,Syndication::FeedPtr,Syndication::ErrorCode)),
            this,
            SLOT(slotFetchPost(Syndication::Loader*,Syndication::FeedPtr,Syndication::ErrorCode)) );
-  loader->loadFrom( "http://www.blogger.com/feeds/" + blogId() + "/posts/default" );
+  loader->loadFrom( QString::fromLatin1("http://www.blogger.com/feeds/%1/posts/default").arg(blogId()));
 }
 
 void GData::modifyPost( KBlog::BlogPost *post )
@@ -744,34 +744,38 @@ void GDataPrivate::slotFetchPost( Syndication::Loader *loader,
 
   bool success = false;
 
-  BlogPost *post = mFetchPostMap[ loader ];
+  BlogPost *post = mFetchPostMap.take( loader );
+  kError() << "Post" << post;
+  post->postId();
 
   if ( status != Syndication::Success ) {
     emit q->errorPost( GData::Atom, i18n( "Could not get posts." ), post );
     return;
   }
+
+  QString postId = post->postId();
   QList<Syndication::ItemPtr> items = feed->items();
   QList<Syndication::ItemPtr>::ConstIterator it = items.constBegin();
   QList<Syndication::ItemPtr>::ConstIterator end = items.constEnd();
   for ( ; it != end; ++it ) {
     QRegExp rx( "post-(\\d+)" );
-    if ( rx.indexIn( ( *it )->id() ) != -1 && rx.cap(1) == post->postId() ){
+    if ( rx.indexIn( ( *it )->id() ) != -1 && rx.cap(1) == postId ){
       kDebug() << "QRegExp rx( 'post-(\\d+)' matches" << rx.cap(1);
       post->setPostId( rx.cap(1) );
       post->setTitle( ( *it )->title() );
       post->setContent( ( *it )->content() );
       post->setStatus( BlogPost::Fetched );
       post->setLink( ( *it )->link() );
-//    FIXME: assuming UTC for now
       post->setCreationDateTime(
         KDateTime( QDateTime::fromTime_t( ( *it )->datePublished() ),
                    KDateTime::Spec::UTC() ).toLocalZone() );
       post->setModificationDateTime(
         KDateTime( QDateTime::fromTime_t( ( *it )->dateUpdated() ),
                    KDateTime::Spec::UTC() ).toLocalZone() );
-      kDebug() << "Emitting fetchedPost( postId=" << post->postId() << ");";
+      kDebug() << "Emitting fetchedPost( postId=" << postId << ");";
       success = true;
       emit q->fetchedPost( post );
+      break;
     }
   }
   if ( !success ) {
@@ -779,7 +783,6 @@ void GDataPrivate::slotFetchPost( Syndication::Loader *loader,
         << mFetchPostMap[ loader ]->postId() << ".";
     emit q->errorPost( GData::Other, i18n( "Could not regexp the blog id path." ), post );
   }
-  mFetchPostMap.remove( loader );
 }
 
 void GDataPrivate::slotCreatePost( KJob *job )
