@@ -49,7 +49,7 @@ static struct
         { 0x002E, I18N_NOOP( "Original Sensitivity" ) },
         { 0x0031, I18N_NOOP( "Report Tag" ) },
         { 0x0036, I18N_NOOP( "Sensitivity" ) },
-        { 0x0037, I18N_NOOP( "Subject" ) },
+        { 0x0037, I18N_NOOP2( "@label The subject of an email", "Subject" ) },
         { 0x0039, I18N_NOOP( "Client Submit Time" ) },
         { 0x003B, I18N_NOOP( "Sent Representing Search Key" ) },
         { 0x003D, I18N_NOOP( "Subject Prefix" ) },
@@ -129,7 +129,7 @@ static struct
         { 0x3A0D, I18N_NOOP( "Location" ) },
         { 0x3A11, I18N_NOOP( "Surname" ) },
         { 0x3A16, I18N_NOOP( "Company Name" ) },
-        { 0x3A17, I18N_NOOP( "Title" ) },
+        { 0x3A17, I18N_NOOP2( "@label The title of a person", "Title" ) },
         { 0x3A18, I18N_NOOP( "Department Name" ) },
         { 0x3A26, I18N_NOOP( "Country" ) },
         { 0x3A27, I18N_NOOP( "Locality" ) },
@@ -141,7 +141,7 @@ static struct
         { 0x0008, I18N_NOOP( "Owner Appointment ID" ) },
         { 0x0009, I18N_NOOP( "Response Requested" ) },
         { 0x8000, I18N_NOOP( "From" ) },
-        { 0x8004, I18N_NOOP( "Subject" ) },
+        { 0x8004, I18N_NOOP2( "@label The subject of an email", "Subject" ) },
         { 0x8005, I18N_NOOP( "Date Sent" ) },
         { 0x8006, I18N_NOOP( "Date Received" ) },
         { 0x8007, I18N_NOOP( "Message Status" ) },
